# -*- mode: python; coding: utf-8 -*-
#
# This example takes a path to an audio file as its first command-line
# argument. The audio is the played with the latest visualization plugin found (if available)
# Play is binded to the 'v' key, and Pause to the 'c' key.

from pgm import render, log, widget
from pgm.layout import window
from pgm.form import rectangle, stream
import sys, pgmrender, gobject

import pygst
pygst.require('0.10')
import gst

render.init('opengl1')

def key_press_cb(event, data):
    global video
    if event.keyval == pgmrender.KEY_ESCAPE:
        sys.exit(0)
    if event.keyval == pgmrender.KEY_c:
        data.pause()
    if event.keyval == pgmrender.KEY_v:
        data.play()
    
def main(args):
    if len(args) != 1:
        print 'Usage: %s <audio_uri>' % sys.argv[0]
        return 1

    rect1 = rectangle.Rectangle(size=(500,300), position=(250,150))
    rect1.ordering = widget.NEAR
    rect1.opacity = 150

    rect2 = rectangle.Rectangle(size=(300,300), position=(50,15))
    rect1.ordering = widget.NEAR

    win = window.Window(title='Visualization', size=(800,600))
    win.add(rect1, rect2)

    def launch(typed_stream):
        playbin = typed_stream.pipeline
        r = gst.registry_get_default()
        l = [x for x in r.get_feature_list(gst.ElementFactory) \
             if (gst.ElementFactory.get_klass(x) == "Visualization")]
        if (l == []):
            return
        e = l.pop() # take latest plugin in the list
        vis_plug = gst.element_factory_make(e.get_name())
        playbin.set_property('vis-plugin', vis_plug)
        rect1.media = typed_stream
        rect2.media = typed_stream
        video.play()

    video = stream.Stream(location=args[0], discovered_callback=launch)

    win.sig_key_press_event.connect(key_press_cb, video)
    win.sig_exit_event.connect(lambda _: sys.exit(0))

    # Start the loop
    gobject.timeout_add(50, win.update)
    win.main()

if __name__ == '__main__':
    sys.exit(main(sys.argv[1:]))
